
Changelog
=========

% <!--next-version-placeholder-->

## v0.1.5 (2023-03-27)
### Fix
* **reBin:** Module renamed to binning, fixes name clashes with docs gen ([`ec959fb`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/ec959fb9e1b51d69cdceaf7784b27df22aa6f4d4))

### Documentation
* **cleanup:** Removed obsolete module doc, replaced by autosummary generated files ([`c0d4256`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/c0d4256a5bcbb83a9a9c0ca0dd3001b9d111cb4b))
* **format:** Fix formatting with black ([`5de80d4`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/5de80d4d528bfb2bf106fa38d2cd8f30f6421f19))
* **General:** Config updated by cookiecutter ([`6c9ddfb`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/6c9ddfb9777cb344378f5a0d86e204dc016a2068))

## v0.1.4 (2023-03-03)
### Fix
* **readme:** License link ([`f98f736`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/f98f7362dd0278210894f138dd7646c8bc92cc9f))

## v0.1.3 (2023-03-03)
### Fix
* **tox:** Clean env ([`0135426`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/013542651eb2bd9a7e2d3b2e8ef837c38501b578))
* **Package:** Cookiecutterrc updated ([`7b29a17`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/7b29a1764f972379086abb51194604423c9714f2))
* **tox:** Cleanup env removed pckg build files ([`ecd8648`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/ecd86485ec0fe67f646d06ca134fe97310f7a3f5))
* **GitHubAction:** Migrate to pathlib.Path in template rendering ([`d3ae5db`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/d3ae5db8f657e929f4139bb17bb746f7b03961d3))

### Documentation
* **readme:** Adjust version numbers in readme as well ([`5700694`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/57006942e6625faf9f36dca1bac0719706b4d000))
* **readme:** Using test.pypi.org links ([`240e58c`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/240e58c87ef0cf0dc3d195f237a09c8e8a717e75))
* **Package:** Update project description ([`704a0b5`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/704a0b50a727ef36f685d27ce068103ffa60ca99))
* **comments:** Add some, remove obsolete ([`efe2689`](https://github.com/BAMresearch/jupyter-analysis-tools/commit/efe2689707f410a18cce331f9cd3732fa2190640))

## v0.1.2 (2023-02-24)
### Fix
* **Documentation:** Doctest format in *distrib* ([`5942972`](https://github.com/BAMresearch/jupyter_analysis_tools/commit/59429724fd41e62c7717fa185e7f5c5c1e5b50d9))

### Documentation
* **distrib:** Generate entries of submodule *distrib* ([`c8055c6`](https://github.com/BAMresearch/jupyter_analysis_tools/commit/c8055c65ac1d49a757ee30f9cd34fc18e8445944))
* **utils:** Generate entries of submodule *utils* ([`762a548`](https://github.com/BAMresearch/jupyter_analysis_tools/commit/762a548a967cf54aed7a58f9d84e4cf6e98e25f7))

## v0.1.1 (2023-02-24)
### Fix
* **docs:** Allow markdown format in changelog ([`593356b`](https://github.com/BAMresearch/jupyter_analysis_tools/commit/593356bb0fb6ea7a6c028b99032ed9742708cb6b))

## v0.1.0 (2022-10-25)
* First release
